==> jc-1.4.0.tar.gz: javax/naming/spi/DirStateFactory__24Result.h <==
// public class javax.naming.spi.DirStateFactory$Result

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 65a7e091dbe07693 javax_naming_spi_DirStateFactory__24Result

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_naming_spi_DirStateFactory__24Result_H_
#define _JC_javax_naming_spi_DirStateFactory__24Result_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_javax_naming_directory_Attributes$object;

// Typedefs
typedef struct _jc_javax_naming_spi_DirStateFactory__24Result$sub_refs	_jc_javax_naming_spi_DirStateFactory__24Result$sub_refs;
typedef struct _jc_javax_naming_spi_DirStateFactory__24Result$sub_nonrefs	_jc_javax_naming_spi_DirStateFactory__24Result$sub_nonrefs;
typedef struct _jc_javax_naming_spi_DirStateFactory__24Result$refs	_jc_javax_naming_spi_DirStateFactory__24Result$refs;
typedef struct _jc_javax_naming_spi_DirStateFactory__24Result$nonrefs	_jc_javax_naming_spi_DirStateFactory__24Result$nonrefs;
typedef struct _jc_javax_naming_spi_DirStateFactory__24Result$object	_jc_javax_naming_spi_DirStateFactory__24Result$object;

typedef const struct _jc_javax_naming_spi_DirStateFactory__24Result$vmethods	_jc_javax_naming_spi_DirStateFactory__24Result$vmethods;
typedef const struct _jc_javax_naming_spi_DirStateFactory__24Result$vtable	_jc_javax_naming_spi_DirStateFactory__24Result$vtable;
typedef const struct _jc_javax_naming_spi_DirStateFactory__24Result$vtype	_jc_javax_naming_spi_DirStateFactory__24Result$vtype;

// Constructors
extern void _jc_javax_naming_spi_DirStateFactory__24Result$method$_init$0db9fd592f801ffe(_jc_env *, struct _jc_javax_naming_spi_DirStateFactory__24Result$object *, struct _jc_java_lang_Object$object *, struct _jc_object *);

// Virtual methods
extern struct _jc_object *_jc_javax_naming_spi_DirStateFactory__24Result$method$getAttributes$de01e608f1e92b33(_jc_env *, struct _jc_javax_naming_spi_DirStateFactory__24Result$object *);
extern struct _jc_java_lang_Object$object *_jc_javax_naming_spi_DirStateFactory__24Result$method$getObject$3a2eec332ceac060(_jc_env *, struct _jc_javax_naming_spi_DirStateFactory__24Result$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_naming_spi_DirStateFactory__24Result$method_info$getAttributes$de01e608f1e92b33;
extern _jc_method _jc_javax_naming_spi_DirStateFactory__24Result$method_info$getObject$3a2eec332ceac060;

// Virtual methods structure
struct _jc_javax_naming_spi_DirStateFactory__24Result$vmethods {
	struct _jc_object	*(*getAttributes$de01e608f1e92b33)(_jc_env *, struct _jc_javax_naming_spi_DirStateFactory__24Result$object *);
	struct _jc_java_lang_Object$object	*(*getObject$3a2eec332ceac060)(_jc_env *, struct _jc_javax_naming_spi_DirStateFactory__24Result$object *);
};

// Vtable
struct _jc_javax_naming_spi_DirStateFactory__24Result$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_naming_spi_DirStateFactory__24Result$vmethods	javax_naming_spi_DirStateFactory__24Result;
};

// Vtype
struct _jc_javax_naming_spi_DirStateFactory__24Result$vtype {
	_jc_type			type;
	_jc_javax_naming_spi_DirStateFactory__24Result$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_naming_spi_DirStateFactory__24Result$sub_refs {
	struct _jc_java_lang_Object$object	*obj;
	struct _jc_object	*outAttrs;
};

// Reference instance fields (object)
struct _jc_javax_naming_spi_DirStateFactory__24Result$refs {
    _jc_javax_naming_spi_DirStateFactory__24Result$sub_refs	javax_naming_spi_DirStateFactory__24Result;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_naming_spi_DirStateFactory__24Result$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_naming_spi_DirStateFactory__24Result$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_naming_spi_DirStateFactory__24Result$sub_nonrefs	javax_naming_spi_DirStateFactory__24Result;
};

// Object instance structure
struct _jc_javax_naming_spi_DirStateFactory__24Result$object {
	_jc_javax_naming_spi_DirStateFactory__24Result$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_naming_spi_DirStateFactory__24Result$vtype	*vtype;
	_jc_javax_naming_spi_DirStateFactory__24Result$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_naming_spi_DirStateFactory__24Result$vtype _jc_javax_naming_spi_DirStateFactory__24Result$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_naming_spi_DirStateFactory__24Result, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_naming_spi_DirStateFactory__24Result$class_object;

#endif	/* _JC_javax_naming_spi_DirStateFactory__24Result_H_ */

==> jc-1.4.6.tar.gz: javax/naming/spi/DirStateFactory__24Result.h <==
// public class javax.naming.spi.DirStateFactory$Result

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 65a7e091dbe07693 javax_naming_spi_DirStateFactory__24Result

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_naming_spi_DirStateFactory__24Result_H_
#define _JC_javax_naming_spi_DirStateFactory__24Result_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_javax_naming_directory_Attributes$object;

// Typedefs
typedef struct _jc_javax_naming_spi_DirStateFactory__24Result$sub_refs	_jc_javax_naming_spi_DirStateFactory__24Result$sub_refs;
typedef struct _jc_javax_naming_spi_DirStateFactory__24Result$sub_nonrefs	_jc_javax_naming_spi_DirStateFactory__24Result$sub_nonrefs;
typedef struct _jc_javax_naming_spi_DirStateFactory__24Result$refs	_jc_javax_naming_spi_DirStateFactory__24Result$refs;
typedef struct _jc_javax_naming_spi_DirStateFactory__24Result$nonrefs	_jc_javax_naming_spi_DirStateFactory__24Result$nonrefs;
typedef struct _jc_javax_naming_spi_DirStateFactory__24Result$object	_jc_javax_naming_spi_DirStateFactory__24Result$object;

typedef const struct _jc_javax_naming_spi_DirStateFactory__24Result$vmethods	_jc_javax_naming_spi_DirStateFactory__24Result$vmethods;
typedef const struct _jc_javax_naming_spi_DirStateFactory__24Result$vtable	_jc_javax_naming_spi_DirStateFactory__24Result$vtable;
typedef const struct _jc_javax_naming_spi_DirStateFactory__24Result$vtype	_jc_javax_naming_spi_DirStateFactory__24Result$vtype;

// Constructors
extern void _jc_javax_naming_spi_DirStateFactory__24Result$method$_init$0db9fd592f801ffe(_jc_env *, struct _jc_javax_naming_spi_DirStateFactory__24Result$object *, struct _jc_java_lang_Object$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_object *_jc_javax_naming_spi_DirStateFactory__24Result$method$getAttributes$de01e608f1e92b33(_jc_env *, struct _jc_javax_naming_spi_DirStateFactory__24Result$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_javax_naming_spi_DirStateFactory__24Result$method$getObject$3a2eec332ceac060(_jc_env *, struct _jc_javax_naming_spi_DirStateFactory__24Result$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_naming_spi_DirStateFactory__24Result$method_info$getAttributes$de01e608f1e92b33;
extern _jc_method _jc_javax_naming_spi_DirStateFactory__24Result$method_info$getObject$3a2eec332ceac060;

// Virtual methods structure
struct _jc_javax_naming_spi_DirStateFactory__24Result$vmethods {
	struct _jc_object	*(*getAttributes$de01e608f1e92b33)(_jc_env *, struct _jc_javax_naming_spi_DirStateFactory__24Result$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*getObject$3a2eec332ceac060)(_jc_env *, struct _jc_javax_naming_spi_DirStateFactory__24Result$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_naming_spi_DirStateFactory__24Result$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_naming_spi_DirStateFactory__24Result$vmethods	javax_naming_spi_DirStateFactory__24Result;
};

// Vtype
struct _jc_javax_naming_spi_DirStateFactory__24Result$vtype {
	_jc_type			type;
	_jc_javax_naming_spi_DirStateFactory__24Result$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_naming_spi_DirStateFactory__24Result$sub_refs {
	struct _jc_java_lang_Object$object	*obj;
	struct _jc_object	*outAttrs;
};

// Reference instance fields (object)
struct _jc_javax_naming_spi_DirStateFactory__24Result$refs {
    _jc_javax_naming_spi_DirStateFactory__24Result$sub_refs	javax_naming_spi_DirStateFactory__24Result;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_naming_spi_DirStateFactory__24Result$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_naming_spi_DirStateFactory__24Result$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_naming_spi_DirStateFactory__24Result$sub_nonrefs	javax_naming_spi_DirStateFactory__24Result;
};

// Object instance structure
struct _jc_javax_naming_spi_DirStateFactory__24Result$object {
	_jc_javax_naming_spi_DirStateFactory__24Result$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_naming_spi_DirStateFactory__24Result$vtype	*vtype;
	_jc_javax_naming_spi_DirStateFactory__24Result$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_naming_spi_DirStateFactory__24Result$vtype _jc_javax_naming_spi_DirStateFactory__24Result$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_naming_spi_DirStateFactory__24Result, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_naming_spi_DirStateFactory__24Result$class_object;

#endif	/* _JC_javax_naming_spi_DirStateFactory__24Result_H_ */
